==> tine20-allinone_2019.12.5.tar.bz2: Filemanager/js/Filemanager-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fr\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Upload Failed"
: "Échec du téléchargement"

, "Putting files in this folder is not allowed!"
: "Impossible d'accéder à ce dossier"

, "Filemanager"
: "Gestionnaire de fichiers"

, "Save locally"
: "Sauvegarder sur le disque"

, "Tags"
: "Tags"

, "Name"
: "Nom"

, "Size"
: "Taille"

, "Contenttype"
: "Type"

, "Folder, Folders"
: [
  "Dossier"
 ,"Dossiers"

]
, "Creation Time"
: "Date et heure de création"

, "Created By"
: "Créé par"

, "Last Modified Time"
: "Dernière modification"

, "Last Modified By"
: "Dernier modificateur"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Télécharger"

, "Open Data Safe"
: ""

, "Folder Up"
: "Dossier parent"

, "Close Data Safe"
: ""

, "Node Download Links"
: ""

, "Url"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Service Unavailable"
: "Service indisponible"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Le gestionnaire de fichier est mal configuré. Se référer à {0} Tine2.0 Admin FAQ {1} ou contacter votre administrateur."

, "Files already exists"
: "Le fichier existe déjà"

, "Do you want to replace the following file(s)?"
: "Voulez-vous remplacer les fichier(s) suivants ?"

, "Failure on create folder"
: "Erreur lors de la création du dossier"

, "Item with this name already exists!"
: "Ce nom est déjà utilisé"

, "Revision"
: "Révision"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "path"
: "Chemin"

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Reload"
: ""

, "Create Folder"
: "Créer dossier"

, "New Folder"
: "ouveau dossier"

, "Please enter the name of the new folder:"
: "Saisir le nom du nouveau dossier"

, "No {0} added"
: "Aucun {0} ajouté"

, "You have to supply a {0} name!"
: "Vous devez fournir un nom à {0}"

, "Edit Properties"
: "Modifier les propriétés"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Saisir le nouveau nom de {0} :"

, "Not renamed {0}"
: "Renommage annulé pour {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Supprimer"

, "Do you really want to delete the following files?"
: "Etes-vous sur de vouloir supprimer les fichiers suivants ?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Publish"
: ""

, "Public download links can be password protected. If left blank anyone who knows the link can download the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "File, Files"
: [
  "Fichier"
 ,"Fichiers"

]
, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Copie en cours... {0}"

, "Moving data .. {0}"
: "Déplacement en cours... {0}"

, "Please wait"
: "Veuillez patienter"

, "Quick Search"
: "Recherche rapide"

, "Type"
: "Type"

, "Description"
: "Description"

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Grants"
: ""

, "This folder has own grants"
: ""

, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
: ""

, "This folder is part of the data safe"
: ""

, "If data safe protection is enabled, this folder and all it's contents is only shown if the data safe is opened."
: ""

, "Sorry, Tine 2.0 would like to show you the contents of the file displayed."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We are happy make you a non-binding offer."
: ""

, "No preview available."
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Remove record"
: ""

, "Search for groups ..."
: ""

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Not yet indexed"
: ""

, "Modified By"
: "Dernier modificateur"

, "Last Modified"
: "Dernière modification"

, "Enter description"
: "Saisir une description"

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Create Public Link"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Usage"
: ""

, "The Quota applies recursively for files and subfolders. Please note, the Effective Quota differs wehn a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "Row double click default"
: ""

, "Defines which action should be executed on double click by default?"
: ""

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Public Download URL"
: ""

, "Serve anonymous downloads from a different URL. Make sure to setup proper rewrite rules."
: ""

, "manage shared folders"
: "Gérer les dossiers partagés"

, "Create new shared folders"
: "Créer un nouveau dossier partagé"

, "Manage anonymous download links"
: ""

, "Allow to see, add and delete download links of files and folders"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path the source has. No action has been performed."
: ""

, "My folders"
: "Mes dossiers"

, "Shared folders"
: "Dossiers partagés"

, "Other users folders"
: "Dossiers des autres utilisateurs"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Folder"
: "Dossier"

, "File"
: "Fichier"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Filemanager/js/Filemanager-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "Nom"

, "Size"
: "Taille"

, "Last Modified"
: "Dernière modification"

, "Description"
: "Description"

, "Folder, Folders"
: [
  "Dossier"
 ,"Dossiers"

]
, "File, Files"
: [
  "Fichier"
 ,"Fichiers"

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "Chemin"

, "URL"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Created By"
: "Créé par"

, "Creation Time"
: "Date et heure de création"

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Dernière modification"

, "Last Modified By"
: "Dernier modificateur"

, "Revision"
: "Révision"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "Échec du téléchargement"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "Tags"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Télécharger"

, "Open Data Safe"
: ""

, "Folder Up"
: "Dossier parent"

, "Close Data Safe"
: ""

, "Filemanager"
: "Gestionnaire de fichiers"

, "Save locally"
: "Sauvegarder sur le disque"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Type"
: "Type"

, "Not yet indexed"
: ""

, "Modified By"
: "Dernier modificateur"

, "Enter description"
: "Saisir une description"

, "Service Unavailable"
: "Service indisponible"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Le gestionnaire de fichier est mal configuré. Se référer à {0} Tine2.0 Admin FAQ {1} ou contacter votre administrateur."

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Voulez-vous remplacer les fichier(s) suivants ?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Ce nom est déjà utilisé"

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "The grant to download files"
: ""

, "Publish"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Copie en cours... {0}"

, "Moving data .. {0}"
: "Déplacement en cours... {0}"

, "Please wait"
: "Veuillez patienter"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: "Recherche rapide"

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Node Download Links"
: ""

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "Créer dossier"

, "New Folder"
: "ouveau dossier"

, "Please enter the name of the new folder:"
: "Saisir le nom du nouveau dossier"

, "No {0} added"
: "Aucun {0} ajouté"

, "You have to supply a {0} name!"
: "Vous devez fournir un nom à {0}"

, "Edit Properties"
: "Modifier les propriétés"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Saisir le nouveau nom de {0} :"

, "Not renamed {0}"
: "Renommage annulé pour {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Supprimer"

, "Do you really want to delete the following files?"
: "Etes-vous sur de vouloir supprimer les fichiers suivants ?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mes dossiers"

, "Shared folders"
: "Dossiers partagés"

, "Other users folders"
: "Dossiers des autres utilisateurs"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "Gérer les dossiers partagés"

, "Create new shared folders"
: "Créer un nouveau dossier partagé"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""





, "Folder"
: "Dossier"

, "File"
: "Fichier"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
